@@ -264,7 +264,7 @@ sub logout {
         <script src="http://html5shiv.googlecode.com/svn/trunk/html5.js"></script>
     <![endif]-->
 </head>
-<body[% IF bodyID %] class="[% bodyID %]"[% END %]>
+<body[% IF bodyID %] id="[% bodyID %]"[% END %]>
     <div class="topbar-wrapper" style="z-index: 5;">
         <div class="topbar">
             <div class="topbar-inner">
